pub trait Platform {
Show 18 methods fn new() -> Self; fn cpu_load(&self) -> Result<DelayedMeasurement<Vec<CPULoad>>>; fn load_average(&self) -> Result<LoadAverage>; fn memory(&self) -> Result<Memory>; fn swap(&self) -> Result<Swap>; fn battery_life(&self) -> Result<BatteryLife>; fn on_ac_power(&self) -> Result<bool>; fn mounts(&self) -> Result<Vec<Filesystem>>; fn block_device_statistics(
        &self
    ) -> Result<BTreeMap<String, BlockDeviceStats>>; fn networks(&self) -> Result<BTreeMap<String, Network>>; fn network_stats(&self, interface: &str) -> Result<NetworkStats>; fn cpu_temp(&self) -> Result<f32>; fn socket_stats(&self) -> Result<SocketStats>; fn cpu_load_aggregate(&self) -> Result<DelayedMeasurement<CPULoad>> { ... } fn memory_and_swap(&self) -> Result<(Memory, Swap)> { ... } fn uptime(&self) -> Result<Duration> { ... } fn boot_time(&self) -> Result<DateTime<Utc>> { ... } fn mount_at<P: AsRef<Path>>(&self, path: P) -> Result<Filesystem> { ... }
}
The Platform trait declares all the functions for getting system information.

NOTE: any impl MUST override one of uptime or boot_time.

Required Methods

Returns a delayed vector of CPU load statistics, one object per CPU (core).

You need to wait some time (about a second is good) before unwrapping the DelayedMeasurement with .done().

Returns a load average object.

Returns a memory information object.

Returns a swap memory information object.

Returns a battery life information object.

Returns whether AC power is plugged in.

Returns a vector of filesystem mount information objects.

Returns a map of block device statistics objects

Returns a map of network intefrace information objects.

It’s a map because most operating systems return an object per IP address, not per interface, and we’re doing deduplication and packing everything into one object per interface. You can use the .values() iterator if you need to iterate over all of them.

Returns statistics for a given interface (bytes/packets sent/received)

Returns the current CPU temperature in degrees Celsius.

Depending on the platform, this might be core 0, package, etc.

Returns information about the number of sockets in use

Provided Methods

Returns a delayed CPU load statistics object, average over all CPUs (cores).

You need to wait some time (about a second is good) before unwrapping the DelayedMeasurement with .done().

Returns a swap and a memory information object. On some platforms this is more efficient than calling memory() and swap() separately If memory() or swap() are not implemented for a platform, this function will fail.

Returns the system uptime.

Returns the system boot time.

Returns a filesystem mount information object for the filesystem at a given path.

Implementors

An implementation of Platform for FreeBSD. See Platform for documentation.